# twacapic

Twitter Academic API Client

In development. Not even ready for experimental use!


## Installation

Install via pip:

`pip install twacapic`


## Dev Install

1. Install [poetry](https://python-poetry.org/docs/#installation)
2. Clone repository
3. In the directory run `poetry install`
4. Run `poetry shell` to start development virtualenv

